.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.postconf`` Ansible role configures Postfix SMTP server according
to autodetected or manually selected parameters. The role uses the
:ref:`debops.postfix` Ansible role to manage Postfix configuration files and lookup
tables.
